@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -28,65 +29,29 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_dbaccess.hxx"
 
-#ifndef _DBA_CORE_QUERYCONTAINER_HXX_
 #include "querycontainer.hxx"
-#endif
-#ifndef DBACCESS_SHARED_DBASTRINGS_HRC
 #include "dbastrings.hrc"
-#endif
-#ifndef _DBA_COREAPI_QUERY_HXX_
 #include "query.hxx"
-#endif
-#ifndef DBACCESS_OBJECTNAMEAPPROVAL_HXX
 #include "objectnameapproval.hxx"
-#endif
-#ifndef DBA_CONTAINERLISTENER_HXX
 #include "ContainerListener.hxx"
-#endif
-#ifndef DBACCESS_VETO_HXX
 #include "veto.hxx"
-#endif
 
 /** === begin UNO includes === **/
-#ifndef _COM_SUN_STAR_BEANS_XPROPERTYSET_HPP_
 #include <com/sun/star/beans/XPropertySet.hpp>
-#endif
-#ifndef _COM_SUN_STAR_CONTAINER_XCONTAINER_HPP_
 #include <com/sun/star/container/XContainer.hpp>
-#endif
-#ifndef _COM_SUN_STAR_SDBC_XCONNECTION_HPP_
 #include <com/sun/star/sdbc/XConnection.hpp>
-#endif
-#ifndef _COM_SUN_STAR_CONTAINER_XCONTAINERAPPROVEBROADCASTER_HPP_
 #include <com/sun/star/container/XContainerApproveBroadcaster.hpp>
-#endif
 /** === end UNO includes === **/
 
-#ifndef _DBHELPER_DBEXCEPTION_HXX_
 #include <connectivity/dbexception.hxx>
-#endif
 
-#ifndef _TOOLS_DEBUG_HXX
 #include <tools/debug.hxx>
-#endif
-#ifndef _COMPHELPER_ENUMHELPER_HXX_
 #include <comphelper/enumhelper.hxx>
-#endif
-#ifndef _COMPHELPER_UNO3_HXX_
 #include <comphelper/uno3.hxx>
-#endif
-#ifndef _COMPHELPER_PROPERTY_HXX_
 #include <comphelper/property.hxx>
-#endif
-#ifndef _COMPHELPER_SEQUENCE_HXX_
 #include <comphelper/sequence.hxx>
-#endif
-#ifndef _COMPHELPER_EXTRACT_HXX_
 #include <comphelper/extract.hxx>
-#endif
-#ifndef _CPPUHELPER_EXC_HLP_HXX_
 #include <cppuhelper/exc_hlp.hxx>
-#endif
 
 using namespace dbtools;
 using namespace ::com::sun::star::uno;
@@ -102,16 +67,14 @@ using namespace ::osl;
 using namespace ::comphelper;
 using namespace ::cppu;
 
-//........................................................................
 namespace dbaccess
 {
-//........................................................................
 
 //==========================================================================
 //= OQueryContainer
 //==========================================================================
 DBG_NAME(OQueryContainer)
-//------------------------------------------------------------------------------
+
 OQueryContainer::OQueryContainer(
                   const Reference< XNameContainer >& _rxCommandDefinitions
                 , const Reference< XConnection >& _rxConn
@@ -128,7 +91,7 @@ OQueryContainer::OQueryContainer(
     {
         m_pCommandsListener = new OContainerListener( *this, m_aMutex );
         m_pCommandsListener->acquire();
-        
+
         Reference< XContainer >	xContainer( m_xCommandDefinitions, UNO_QUERY_THROW );
         xContainer->addContainerListener( m_pCommandsListener );
 
@@ -151,20 +114,17 @@ OQueryContainer::OQueryContainer(
     setElementApproval( PContainerApprove( new ObjectNameApproval( _rxConn, ObjectNameApproval::TypeQuery ) ) );
 }
 
-//------------------------------------------------------------------------------
 OQueryContainer::~OQueryContainer()
 {
     DBG_DTOR(OQueryContainer, NULL);
     //	dispose();
         //	maybe we're already disposed, but this should be uncritical
 }
-// -----------------------------------------------------------------------------
+
 IMPLEMENT_FORWARD_XINTERFACE2( OQueryContainer,ODefinitionContainer,OQueryContainer_Base)
 
-//------------------------------------------------------------------------------
 IMPLEMENT_FORWARD_XTYPEPROVIDER2( OQueryContainer,ODefinitionContainer,OQueryContainer_Base)
 
-//------------------------------------------------------------------------------
 void OQueryContainer::disposing()
 {
     ODefinitionContainer::disposing();
@@ -190,18 +150,15 @@ void OQueryContainer::disposing()
 }
 
 // XServiceInfo
-//------------------------------------------------------------------------------
 IMPLEMENT_SERVICE_INFO2(OQueryContainer, "com.sun.star.sdb.dbaccess.OQueryContainer", SERVICE_SDBCX_CONTAINER, SERVICE_SDB_QUERIES)
 
 // XDataDescriptorFactory
-//--------------------------------------------------------------------------
 Reference< XPropertySet > SAL_CALL OQueryContainer::createDataDescriptor(  ) throw(RuntimeException)
 {
     return new OQueryDescriptor();
 }
 
 // XAppend
-//------------------------------------------------------------------------------
 void SAL_CALL OQueryContainer::appendByDescriptor( const Reference< XPropertySet >& _rxDesc ) throw(SQLException, ElementExistException, RuntimeException)
 {
     ResettableMutexGuard aGuard(m_aMutex);
@@ -242,7 +199,6 @@ void SAL_CALL OQueryContainer::appendByDescriptor( const Reference< XPropertySet
 }
 
 // XDrop
-//------------------------------------------------------------------------------
 void SAL_CALL OQueryContainer::dropByName( const ::rtl::OUString& _rName ) throw(SQLException, NoSuchElementException, RuntimeException)
 {
     MutexGuard aGuard(m_aMutex);
@@ -257,7 +213,6 @@ void SAL_CALL OQueryContainer::dropByName( const ::rtl::OUString& _rName ) throw
     m_xCommandDefinitions->removeByName(_rName);
 }
 
-//------------------------------------------------------------------------------
 void SAL_CALL OQueryContainer::dropByIndex( sal_Int32 _nIndex ) throw(SQLException, IndexOutOfBoundsException, RuntimeException)
 {
     MutexGuard aGuard(m_aMutex);
@@ -274,7 +229,7 @@ void SAL_CALL OQueryContainer::dropByIndex( sal_Int32 _nIndex ) throw(SQLExcepti
 
     dropByName(sName);
 }
-//------------------------------------------------------------------------------
+
 void SAL_CALL OQueryContainer::elementInserted( const ::com::sun::star::container::ContainerEvent& _rEvent ) throw(::com::sun::star::uno::RuntimeException)
 {
     Reference< XContent > xNewElement;
@@ -297,7 +252,6 @@ void SAL_CALL OQueryContainer::elementInserted( const ::com::sun::star::containe
     insertByName(sElementName,makeAny(xNewElement));
 }
 
-//------------------------------------------------------------------------------
 void SAL_CALL OQueryContainer::elementRemoved( const ::com::sun::star::container::ContainerEvent& _rEvent ) throw(::com::sun::star::uno::RuntimeException)
 {
     ::rtl::OUString sAccessor;
@@ -311,7 +265,6 @@ void SAL_CALL OQueryContainer::elementRemoved( const ::com::sun::star::container
     removeByName(sAccessor);
 }
 
-//------------------------------------------------------------------------------
 void SAL_CALL OQueryContainer::elementReplaced( const ::com::sun::star::container::ContainerEvent& _rEvent ) throw(::com::sun::star::uno::RuntimeException)
 {
     Reference< XPropertySet > xReplacedElement;
@@ -325,14 +278,13 @@ void SAL_CALL OQueryContainer::elementReplaced( const ::com::sun::star::containe
         DBG_ASSERT(m_aDocumentMap.find(sAccessor) != m_aDocumentMap.end(), "OQueryContainer::elementReplaced         : oops .... we're inconsistent with our master container !");
         if (!sAccessor.getLength() || !hasByName(sAccessor))
             return;
-        
+
         xNewElement = implCreateWrapper(sAccessor);
     }
 
     replaceByName(sAccessor,makeAny(xNewElement));
 }
 
-//------------------------------------------------------------------------------
 Reference< XVeto > SAL_CALL OQueryContainer::approveInsertElement( const ContainerEvent& Event ) throw (WrappedTargetException, RuntimeException)
 {
     ::rtl::OUString sName;
@@ -351,19 +303,16 @@ Reference< XVeto > SAL_CALL OQueryContainer::approveInsertElement( const Contain
     return xReturn;
 }
 
-//------------------------------------------------------------------------------
 Reference< XVeto > SAL_CALL OQueryContainer::approveReplaceElement( const ContainerEvent& /*Event*/ ) throw (WrappedTargetException, RuntimeException)
 {
     return NULL;
 }
 
-//------------------------------------------------------------------------------
 Reference< XVeto > SAL_CALL OQueryContainer::approveRemoveElement( const ContainerEvent& /*Event*/ ) throw (WrappedTargetException, RuntimeException)
 {
     return NULL;
 }
 
-//------------------------------------------------------------------------------
 void SAL_CALL OQueryContainer::disposing( const ::com::sun::star::lang::EventObject& _rSource ) throw(::com::sun::star::uno::RuntimeException)
 {
     if (_rSource.Source.get() == Reference< XInterface >(m_xCommandDefinitions, UNO_QUERY).get())
@@ -371,7 +320,7 @@ void SAL_CALL OQueryContainer::disposing( const ::com::sun::star::lang::EventObj
         DBG_ERROR("OQueryContainer::disposing : nobody should dispose the CommandDefinition container before disposing my connection !");
         dispose();
     }
-    else 
+    else
     {
         Reference< XContent > xSource(_rSource.Source, UNO_QUERY);
         // it's one of our documents ....
@@ -389,20 +338,17 @@ void SAL_CALL OQueryContainer::disposing( const ::com::sun::star::lang::EventObj
     }
 }
 
-// -----------------------------------------------------------------------------
 ::rtl::OUString OQueryContainer::determineContentType() const
 {
     return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "application/vnd.org.openoffice.DatabaseQueryContainer" ) );
 }
 
-// -----------------------------------------------------------------------------
 Reference< XContent > OQueryContainer::implCreateWrapper(const ::rtl::OUString& _rName)
 {
     Reference< XContent > xObject(m_xCommandDefinitions->getByName(_rName),UNO_QUERY);
     return implCreateWrapper(xObject);
 }
 
-//--------------------------------------------------------------------------
 Reference< XContent > OQueryContainer::implCreateWrapper(const Reference< XContent >& _rxCommandDesc)
 {
     Reference<XNameContainer> xContainer(_rxCommandDesc,UNO_QUERY);
@@ -424,12 +370,12 @@ Reference< XContent > OQueryContainer::implCreateWrapper(const Reference< XConte
 
     return xReturn;
 }
-//--------------------------------------------------------------------------
+
 Reference< XContent > OQueryContainer::createObject( const ::rtl::OUString& _rName)
 {
     return implCreateWrapper(_rName);
 }
-// -----------------------------------------------------------------------------
+
 sal_Bool OQueryContainer::checkExistence(const ::rtl::OUString& _rName)
 {
     sal_Bool bRet = sal_False;
@@ -449,19 +395,19 @@ sal_Bool OQueryContainer::checkExistence(const ::rtl::OUString& _rName)
     }
     return bRet;
 }
-//--------------------------------------------------------------------------
+
 sal_Bool SAL_CALL OQueryContainer::hasElements( ) throw (RuntimeException)
 {
     MutexGuard aGuard(m_aMutex);
     return m_xCommandDefinitions->hasElements();
 }
-// -----------------------------------------------------------------------------
+
 sal_Int32 SAL_CALL OQueryContainer::getCount(  ) throw(RuntimeException)
 {
     MutexGuard aGuard(m_aMutex);
     return Reference<XIndexAccess>(m_xCommandDefinitions,UNO_QUERY)->getCount();
 }
-// -----------------------------------------------------------------------------
+
 Sequence< ::rtl::OUString > SAL_CALL OQueryContainer::getElementNames(  ) throw(RuntimeException)
 {
     MutexGuard aGuard(m_aMutex);
@@ -469,7 +415,5 @@ Sequence< ::rtl::OUString > SAL_CALL OQueryContainer::getElementNames(  ) throw(
     return m_xCommandDefinitions->getElementNames();
 }
 
-//........................................................................
 }	// namespace dbaccess
-//........................................................................
-
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
